@@ -21,7 +21,7 @@ use Net::Stripe::BalanceTransaction;
 use Net::Stripe::List;
 use Net::Stripe::LineItem;
 
-our $VERSION = '0.09';
+our $VERSION = '0.15';
 
 # ABSTRACT: API client for Stripe.com
 
@@ -105,23 +105,37 @@ BalanceTransactions: {
 
 
 Customers: {
-    method post_customer(Net::Stripe::Customer :$customer?,
+    method post_customer(Net::Stripe::Customer|Str :$customer?,
                          Int :$account_balance?,
                          Net::Stripe::Card|Net::Stripe::Token|Str|HashRef :$card?,
                          Str :$coupon?,
+                         Str :$default_card?,
                          Str :$description?,
                          Str :$email?, 
                          HashRef :$metadata?, 
                          Str :$plan?, 
                          Int :$quantity?, 
                          Int :$trial_end?) {
-        if ($customer) {
-            return $self->_post("customers/" . $customer->id, $customer);
-        }
 
         if (defined($card) && ref($card) eq 'HASH') {
             $card = Net::Stripe::Card->new($card);
         } 
+        
+        if (ref($customer) eq 'Net::Stripe::Customer') {
+            return $self->_post("customers/" . $customer->id, $customer);
+        } elsif (defined($customer)) {
+            my %args = (
+                account_balance => $account_balance,
+                card => $card,
+                coupon => $coupon,
+                default_card => $default_card,
+                email => $email,
+                metadata => $metadata,
+            );
+    
+            return $self->_post("customers/" . $customer, _defined_arguments(\%args));
+        }
+
 
         $customer = Net::Stripe::Customer->new(account_balance => $account_balance,
                                                card => $card,
@@ -259,15 +273,13 @@ Subscriptions: {
                     quantity => $quantity,
                     application_fee_percent => $application_fee_percent);
 
-        map { delete $args{$_} } grep {  !defined($args{$_}) } keys %args;
-
         if (ref($subscription) && $subscription eq 'Net::Stripe::Subscription') {
             return $self->_post("customers/$customer/subscriptions/" . $subscription->id, $subscription);
         } elsif (defined($subscription) && !ref($subscription)) {
-            return $self->_post("customers/$customer/subscriptions/" . $subscription, \%args);
+            return $self->_post("customers/$customer/subscriptions/" . $subscription, _defined_arguments(\%args));
         }
         
-        return $self->_post("customers/$customer/subscriptions", \%args);
+        return $self->_post("customers/$customer/subscriptions", _defined_arguments(\%args));
     }
     
     method delete_subscription(Net::Stripe::Customer|Str :$customer,
@@ -579,9 +591,25 @@ method _delete(Str $path) {
     return $self->_make_request($req);
 }
 
+sub convert_to_form_fields {
+    my $hash = shift;
+    if (ref($hash) eq 'HASH') {
+        foreach my $key (keys %$hash) {
+            if (ref($hash->{$key}) =~ /^Net::Stripe/) {
+                my %fields = $hash->{$key}->form_fields();
+                foreach my $fn (keys %fields) {
+                    $hash->{$fn} = $fields{$fn};
+                }
+                delete $hash->{$key};
+            }
+        }
+    }
+    return $hash;
+}
+
 method _post(Str $path, $obj?) {
     my $req = POST $self->api_base . '/' . $path, 
-        ($obj ? (Content => [ref($obj) eq 'HASH' ? %$obj : $obj->form_fields]) : ());
+        ($obj ? (Content => [ref($obj) eq 'HASH' ? %{convert_to_form_fields($obj)} : $obj->form_fields]) : ());
     return $self->_make_request($req);
 }
 
@@ -624,6 +652,12 @@ method _make_request($req) {
     die $e;
 }
 
+sub _defined_arguments {
+    my $args = shift;
+
+    map { delete $args->{$_} } grep {  !defined($args->{$_}) } keys %$args;
+    return $args;
+}
 
 sub _hash_to_object {
     my $hash   = shift;
@@ -653,7 +687,7 @@ sub _hash_to_object {
 method _build_api_base { 'https://api.stripe.com/v1' }
 
 method _build_ua {
-    my $ua = LWP::UserAgent->new();
+    my $ua = LWP::UserAgent->new(keep_alive => 4);
     $ua->agent("Net::Stripe/$VERSION");
     return $ua;
 }
@@ -672,7 +706,7 @@ Net::Stripe - API client for Stripe.com
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -731,6 +765,8 @@ Reader: api_base
 
 Type: Str
 
+Additional documentation: This is the base part of the URL for every request made
+
 =head2 api_key
 
 Reader: api_key
@@ -739,6 +775,8 @@ Type: Str
 
 This attribute is required.
 
+Additional documentation: You get this from your Stripe Account settings
+
 =head2 debug
 
 Reader: debug
